prefecture

# XMLRésuméLibrary: User Guide

postalCode | Element Reference | present

## Name

prefecture — A name of a prefecture or other administrative district

## Synopsis

### Content Model

    (#PCDATA)

### Attributes

Name | Type | Default
--- | --- | ---
id | ID | None
targets | CDATA | None

## Description

The `prefecture` element contains the name of a prefecture or other administrative district of a city, province, state, or other area.

This element is currently ignored during formatting.

### Parents

`prefecture` may be contained in these elements: `address`

### Attributes

`id`

  A string used to uniquely identify a prefecture. The prefecture may then be referred to by this identifier.

## See Also

`city`, `county`, `state`, `suburb`, `ward`.

## Examples

    <prefecture>Basilius</prefecture>

postalCode | Element Reference | present